pub struct CocoonServiceClient<T> {
inner: Grpc<T>,
}Expand description
Service running on the Cocoon sidecar, listening for requests from Mountain.
Fields
inner: Grpc<T>Implementations
Sourceimpl CocoonServiceClient<Channel>
impl CocoonServiceClient<Channel>
Sourceimpl<T> CocoonServiceClient<T>
impl<T> CocoonServiceClient<T>
pub fn new(inner: T) -> Self
pub fn with_origin(inner: T, origin: Uri) -> Self
pub fn with_interceptor<F>( inner: T, interceptor: F, ) -> CocoonServiceClient<InterceptedService<T, F>>
Sourcepub fn send_compressed(self, encoding: CompressionEncoding) -> Self
pub fn send_compressed(self, encoding: CompressionEncoding) -> Self
Compress requests with the given encoding.
This requires the server to support it otherwise it might respond with an error.
Sourcepub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
Enable decompressing responses.
Sourcepub fn max_decoding_message_size(self, limit: usize) -> Self
pub fn max_decoding_message_size(self, limit: usize) -> Self
Limits the maximum size of a decoded message.
Default: 4MB
Sourcepub fn max_encoding_message_size(self, limit: usize) -> Self
pub fn max_encoding_message_size(self, limit: usize) -> Self
Limits the maximum size of an encoded message.
Default: usize::MAX
Sourcepub async fn process_mountain_request(
&mut self,
request: impl IntoRequest<GenericRequest>,
) -> Result<Response<GenericResponse>, Status>
pub async fn process_mountain_request( &mut self, request: impl IntoRequest<GenericRequest>, ) -> Result<Response<GenericResponse>, Status>
A generic request-response method for Mountain to call a function on Cocoon.
Sourcepub async fn send_mountain_notification(
&mut self,
request: impl IntoRequest<GenericNotification>,
) -> Result<Response<Empty>, Status>
pub async fn send_mountain_notification( &mut self, request: impl IntoRequest<GenericNotification>, ) -> Result<Response<Empty>, Status>
A generic fire-and-forget method for Mountain to send a notification to Cocoon.
Sourcepub async fn cancel_operation(
&mut self,
request: impl IntoRequest<CancelOperationRequest>,
) -> Result<Response<Empty>, Status>
pub async fn cancel_operation( &mut self, request: impl IntoRequest<CancelOperationRequest>, ) -> Result<Response<Empty>, Status>
A method for Mountain to request that Cocoon cancel a long-running operation.
Sourcepub async fn initial_handshake(
&mut self,
request: impl IntoRequest<Empty>,
) -> Result<Response<Empty>, Status>
pub async fn initial_handshake( &mut self, request: impl IntoRequest<Empty>, ) -> Result<Response<Empty>, Status>
Handshake - Called by Cocoon to signal readiness
Sourcepub async fn init_extension_host(
&mut self,
request: impl IntoRequest<InitExtensionHostRequest>,
) -> Result<Response<Empty>, Status>
pub async fn init_extension_host( &mut self, request: impl IntoRequest<InitExtensionHostRequest>, ) -> Result<Response<Empty>, Status>
Initialize Extension Host - Mountain sends initialization data to Cocoon
Sourcepub async fn register_command(
&mut self,
request: impl IntoRequest<RegisterCommandRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_command( &mut self, request: impl IntoRequest<RegisterCommandRequest>, ) -> Result<Response<Empty>, Status>
Register Command - Cocoon registers an extension command
Sourcepub async fn execute_contributed_command(
&mut self,
request: impl IntoRequest<ExecuteCommandRequest>,
) -> Result<Response<ExecuteCommandResponse>, Status>
pub async fn execute_contributed_command( &mut self, request: impl IntoRequest<ExecuteCommandRequest>, ) -> Result<Response<ExecuteCommandResponse>, Status>
Execute Contributed Command - Mountain executes an extension command
Sourcepub async fn unregister_command(
&mut self,
request: impl IntoRequest<UnregisterCommandRequest>,
) -> Result<Response<Empty>, Status>
pub async fn unregister_command( &mut self, request: impl IntoRequest<UnregisterCommandRequest>, ) -> Result<Response<Empty>, Status>
Unregister Command - Unregister a previously registered command
Sourcepub async fn register_hover_provider(
&mut self,
request: impl IntoRequest<RegisterProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_hover_provider( &mut self, request: impl IntoRequest<RegisterProviderRequest>, ) -> Result<Response<Empty>, Status>
Register Hover Provider - Register a hover provider
Sourcepub async fn provide_hover(
&mut self,
request: impl IntoRequest<ProvideHoverRequest>,
) -> Result<Response<ProvideHoverResponse>, Status>
pub async fn provide_hover( &mut self, request: impl IntoRequest<ProvideHoverRequest>, ) -> Result<Response<ProvideHoverResponse>, Status>
Provide Hover - Request hover information
Sourcepub async fn register_completion_item_provider(
&mut self,
request: impl IntoRequest<RegisterProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_completion_item_provider( &mut self, request: impl IntoRequest<RegisterProviderRequest>, ) -> Result<Response<Empty>, Status>
Register Completion Item Provider - Register a completion provider
Sourcepub async fn provide_completion_items(
&mut self,
request: impl IntoRequest<ProvideCompletionItemsRequest>,
) -> Result<Response<ProvideCompletionItemsResponse>, Status>
pub async fn provide_completion_items( &mut self, request: impl IntoRequest<ProvideCompletionItemsRequest>, ) -> Result<Response<ProvideCompletionItemsResponse>, Status>
Provide Completion Items - Request completion items
Sourcepub async fn register_definition_provider(
&mut self,
request: impl IntoRequest<RegisterProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_definition_provider( &mut self, request: impl IntoRequest<RegisterProviderRequest>, ) -> Result<Response<Empty>, Status>
Register Definition Provider - Register a definition provider
Sourcepub async fn provide_definition(
&mut self,
request: impl IntoRequest<ProvideDefinitionRequest>,
) -> Result<Response<ProvideDefinitionResponse>, Status>
pub async fn provide_definition( &mut self, request: impl IntoRequest<ProvideDefinitionRequest>, ) -> Result<Response<ProvideDefinitionResponse>, Status>
Provide Definition - Request definition location
Sourcepub async fn register_reference_provider(
&mut self,
request: impl IntoRequest<RegisterProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_reference_provider( &mut self, request: impl IntoRequest<RegisterProviderRequest>, ) -> Result<Response<Empty>, Status>
Register Reference Provider - Register a reference provider
Sourcepub async fn provide_references(
&mut self,
request: impl IntoRequest<ProvideReferencesRequest>,
) -> Result<Response<ProvideReferencesResponse>, Status>
pub async fn provide_references( &mut self, request: impl IntoRequest<ProvideReferencesRequest>, ) -> Result<Response<ProvideReferencesResponse>, Status>
Provide References - Request references
Sourcepub async fn register_code_actions_provider(
&mut self,
request: impl IntoRequest<RegisterProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_code_actions_provider( &mut self, request: impl IntoRequest<RegisterProviderRequest>, ) -> Result<Response<Empty>, Status>
Register Code Actions Provider - Register code actions provider
Sourcepub async fn provide_code_actions(
&mut self,
request: impl IntoRequest<ProvideCodeActionsRequest>,
) -> Result<Response<ProvideCodeActionsResponse>, Status>
pub async fn provide_code_actions( &mut self, request: impl IntoRequest<ProvideCodeActionsRequest>, ) -> Result<Response<ProvideCodeActionsResponse>, Status>
Provide Code Actions - Request code actions
Sourcepub async fn show_text_document(
&mut self,
request: impl IntoRequest<ShowTextDocumentRequest>,
) -> Result<Response<ShowTextDocumentResponse>, Status>
pub async fn show_text_document( &mut self, request: impl IntoRequest<ShowTextDocumentRequest>, ) -> Result<Response<ShowTextDocumentResponse>, Status>
Show Text Document - Open a text document
Sourcepub async fn show_information_message(
&mut self,
request: impl IntoRequest<ShowMessageRequest>,
) -> Result<Response<ShowMessageResponse>, Status>
pub async fn show_information_message( &mut self, request: impl IntoRequest<ShowMessageRequest>, ) -> Result<Response<ShowMessageResponse>, Status>
Show Information Message - Display an info message
Sourcepub async fn show_warning_message(
&mut self,
request: impl IntoRequest<ShowMessageRequest>,
) -> Result<Response<ShowMessageResponse>, Status>
pub async fn show_warning_message( &mut self, request: impl IntoRequest<ShowMessageRequest>, ) -> Result<Response<ShowMessageResponse>, Status>
Show Warning Message - Display a warning message
Sourcepub async fn show_error_message(
&mut self,
request: impl IntoRequest<ShowMessageRequest>,
) -> Result<Response<ShowMessageResponse>, Status>
pub async fn show_error_message( &mut self, request: impl IntoRequest<ShowMessageRequest>, ) -> Result<Response<ShowMessageResponse>, Status>
Show Error Message - Display an error message
Sourcepub async fn create_status_bar_item(
&mut self,
request: impl IntoRequest<CreateStatusBarItemRequest>,
) -> Result<Response<CreateStatusBarItemResponse>, Status>
pub async fn create_status_bar_item( &mut self, request: impl IntoRequest<CreateStatusBarItemRequest>, ) -> Result<Response<CreateStatusBarItemResponse>, Status>
Create Status Bar Item - Create a status bar item
Sourcepub async fn set_status_bar_text(
&mut self,
request: impl IntoRequest<SetStatusBarTextRequest>,
) -> Result<Response<Empty>, Status>
pub async fn set_status_bar_text( &mut self, request: impl IntoRequest<SetStatusBarTextRequest>, ) -> Result<Response<Empty>, Status>
Set Status Bar Text - Set status bar text
Sourcepub async fn create_webview_panel(
&mut self,
request: impl IntoRequest<CreateWebviewPanelRequest>,
) -> Result<Response<CreateWebviewPanelResponse>, Status>
pub async fn create_webview_panel( &mut self, request: impl IntoRequest<CreateWebviewPanelRequest>, ) -> Result<Response<CreateWebviewPanelResponse>, Status>
Create Webview Panel - Create a new webview panel
Sourcepub async fn set_webview_html(
&mut self,
request: impl IntoRequest<SetWebviewHtmlRequest>,
) -> Result<Response<Empty>, Status>
pub async fn set_webview_html( &mut self, request: impl IntoRequest<SetWebviewHtmlRequest>, ) -> Result<Response<Empty>, Status>
Set Webview HTML - Update webview HTML content
Sourcepub async fn on_did_receive_message(
&mut self,
request: impl IntoRequest<OnDidReceiveMessageRequest>,
) -> Result<Response<Empty>, Status>
pub async fn on_did_receive_message( &mut self, request: impl IntoRequest<OnDidReceiveMessageRequest>, ) -> Result<Response<Empty>, Status>
On Did Receive Message - Receive message from webview
Sourcepub async fn read_file(
&mut self,
request: impl IntoRequest<ReadFileRequest>,
) -> Result<Response<ReadFileResponse>, Status>
pub async fn read_file( &mut self, request: impl IntoRequest<ReadFileRequest>, ) -> Result<Response<ReadFileResponse>, Status>
Read File - Read file contents
Sourcepub async fn write_file(
&mut self,
request: impl IntoRequest<WriteFileRequest>,
) -> Result<Response<Empty>, Status>
pub async fn write_file( &mut self, request: impl IntoRequest<WriteFileRequest>, ) -> Result<Response<Empty>, Status>
Write File - Write file contents
Sourcepub async fn stat(
&mut self,
request: impl IntoRequest<StatRequest>,
) -> Result<Response<StatResponse>, Status>
pub async fn stat( &mut self, request: impl IntoRequest<StatRequest>, ) -> Result<Response<StatResponse>, Status>
Stat - Get file metadata
Sourcepub async fn readdir(
&mut self,
request: impl IntoRequest<ReaddirRequest>,
) -> Result<Response<ReaddirResponse>, Status>
pub async fn readdir( &mut self, request: impl IntoRequest<ReaddirRequest>, ) -> Result<Response<ReaddirResponse>, Status>
Read Directory - List directory contents
Sourcepub async fn watch_file(
&mut self,
request: impl IntoRequest<WatchFileRequest>,
) -> Result<Response<Empty>, Status>
pub async fn watch_file( &mut self, request: impl IntoRequest<WatchFileRequest>, ) -> Result<Response<Empty>, Status>
Watch File - Watch file for changes
Sourcepub async fn find_files(
&mut self,
request: impl IntoRequest<FindFilesRequest>,
) -> Result<Response<FindFilesResponse>, Status>
pub async fn find_files( &mut self, request: impl IntoRequest<FindFilesRequest>, ) -> Result<Response<FindFilesResponse>, Status>
Find Files - Search for files
Sourcepub async fn find_text_in_files(
&mut self,
request: impl IntoRequest<FindTextInFilesRequest>,
) -> Result<Response<FindTextInFilesResponse>, Status>
pub async fn find_text_in_files( &mut self, request: impl IntoRequest<FindTextInFilesRequest>, ) -> Result<Response<FindTextInFilesResponse>, Status>
Find Text in Files - Search for text across files
Sourcepub async fn open_document(
&mut self,
request: impl IntoRequest<OpenDocumentRequest>,
) -> Result<Response<OpenDocumentResponse>, Status>
pub async fn open_document( &mut self, request: impl IntoRequest<OpenDocumentRequest>, ) -> Result<Response<OpenDocumentResponse>, Status>
Open Document - Open a document
Sourcepub async fn save_all(
&mut self,
request: impl IntoRequest<SaveAllRequest>,
) -> Result<Response<SaveAllResponse>, Status>
pub async fn save_all( &mut self, request: impl IntoRequest<SaveAllRequest>, ) -> Result<Response<SaveAllResponse>, Status>
Save All - Save all open documents
Sourcepub async fn apply_edit(
&mut self,
request: impl IntoRequest<ApplyEditRequest>,
) -> Result<Response<ApplyEditResponse>, Status>
pub async fn apply_edit( &mut self, request: impl IntoRequest<ApplyEditRequest>, ) -> Result<Response<ApplyEditResponse>, Status>
Apply Edit - Apply a text edit to a document
Sourcepub async fn update_configuration(
&mut self,
request: impl IntoRequest<UpdateConfigurationRequest>,
) -> Result<Response<Empty>, Status>
pub async fn update_configuration( &mut self, request: impl IntoRequest<UpdateConfigurationRequest>, ) -> Result<Response<Empty>, Status>
Update Configuration - Notify of configuration changes
Sourcepub async fn update_workspace_folders(
&mut self,
request: impl IntoRequest<UpdateWorkspaceFoldersRequest>,
) -> Result<Response<Empty>, Status>
pub async fn update_workspace_folders( &mut self, request: impl IntoRequest<UpdateWorkspaceFoldersRequest>, ) -> Result<Response<Empty>, Status>
Update Workspace Folders - Update workspace folders
Sourcepub async fn open_terminal(
&mut self,
request: impl IntoRequest<OpenTerminalRequest>,
) -> Result<Response<Empty>, Status>
pub async fn open_terminal( &mut self, request: impl IntoRequest<OpenTerminalRequest>, ) -> Result<Response<Empty>, Status>
Open Terminal - Open a new terminal
Sourcepub async fn terminal_input(
&mut self,
request: impl IntoRequest<TerminalInputRequest>,
) -> Result<Response<Empty>, Status>
pub async fn terminal_input( &mut self, request: impl IntoRequest<TerminalInputRequest>, ) -> Result<Response<Empty>, Status>
Terminal Input - Send input to terminal
Sourcepub async fn close_terminal(
&mut self,
request: impl IntoRequest<CloseTerminalRequest>,
) -> Result<Response<Empty>, Status>
pub async fn close_terminal( &mut self, request: impl IntoRequest<CloseTerminalRequest>, ) -> Result<Response<Empty>, Status>
Close Terminal - Close a terminal
Sourcepub async fn accept_terminal_opened(
&mut self,
request: impl IntoRequest<TerminalOpenedNotification>,
) -> Result<Response<Empty>, Status>
pub async fn accept_terminal_opened( &mut self, request: impl IntoRequest<TerminalOpenedNotification>, ) -> Result<Response<Empty>, Status>
Accept Terminal Opened - Notification: Terminal opened
Sourcepub async fn accept_terminal_closed(
&mut self,
request: impl IntoRequest<TerminalClosedNotification>,
) -> Result<Response<Empty>, Status>
pub async fn accept_terminal_closed( &mut self, request: impl IntoRequest<TerminalClosedNotification>, ) -> Result<Response<Empty>, Status>
Accept Terminal Closed - Notification: Terminal closed
Sourcepub async fn accept_terminal_process_id(
&mut self,
request: impl IntoRequest<TerminalProcessIdNotification>,
) -> Result<Response<Empty>, Status>
pub async fn accept_terminal_process_id( &mut self, request: impl IntoRequest<TerminalProcessIdNotification>, ) -> Result<Response<Empty>, Status>
Accept Terminal Process ID - Notification: Terminal process ID
Sourcepub async fn accept_terminal_process_data(
&mut self,
request: impl IntoRequest<TerminalDataNotification>,
) -> Result<Response<Empty>, Status>
pub async fn accept_terminal_process_data( &mut self, request: impl IntoRequest<TerminalDataNotification>, ) -> Result<Response<Empty>, Status>
Accept Terminal Process Data - Notification: Terminal output
Sourcepub async fn register_tree_view_provider(
&mut self,
request: impl IntoRequest<RegisterTreeViewProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_tree_view_provider( &mut self, request: impl IntoRequest<RegisterTreeViewProviderRequest>, ) -> Result<Response<Empty>, Status>
Register Tree View Provider - Register a tree view provider
Sourcepub async fn get_tree_children(
&mut self,
request: impl IntoRequest<GetTreeChildrenRequest>,
) -> Result<Response<GetTreeChildrenResponse>, Status>
pub async fn get_tree_children( &mut self, request: impl IntoRequest<GetTreeChildrenRequest>, ) -> Result<Response<GetTreeChildrenResponse>, Status>
Get Tree Children - Request tree view children
Sourcepub async fn register_scm_provider(
&mut self,
request: impl IntoRequest<RegisterScmProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_scm_provider( &mut self, request: impl IntoRequest<RegisterScmProviderRequest>, ) -> Result<Response<Empty>, Status>
Register SCM Provider - Register source control provider
Sourcepub async fn update_scm_group(
&mut self,
request: impl IntoRequest<UpdateScmGroupRequest>,
) -> Result<Response<Empty>, Status>
pub async fn update_scm_group( &mut self, request: impl IntoRequest<UpdateScmGroupRequest>, ) -> Result<Response<Empty>, Status>
Update SCM Group - Update SCM group
Sourcepub async fn git_exec(
&mut self,
request: impl IntoRequest<GitExecRequest>,
) -> Result<Response<GitExecResponse>, Status>
pub async fn git_exec( &mut self, request: impl IntoRequest<GitExecRequest>, ) -> Result<Response<GitExecResponse>, Status>
Execute Git - Execute git command
Sourcepub async fn register_debug_adapter(
&mut self,
request: impl IntoRequest<RegisterDebugAdapterRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_debug_adapter( &mut self, request: impl IntoRequest<RegisterDebugAdapterRequest>, ) -> Result<Response<Empty>, Status>
Register Debug Adapter - Register debug adapter
Sourcepub async fn start_debugging(
&mut self,
request: impl IntoRequest<StartDebuggingRequest>,
) -> Result<Response<StartDebuggingResponse>, Status>
pub async fn start_debugging( &mut self, request: impl IntoRequest<StartDebuggingRequest>, ) -> Result<Response<StartDebuggingResponse>, Status>
Start Debugging - Start debug session
Sourcepub async fn participate_in_save(
&mut self,
request: impl IntoRequest<ParticipateInSaveRequest>,
) -> Result<Response<ParticipateInSaveResponse>, Status>
pub async fn participate_in_save( &mut self, request: impl IntoRequest<ParticipateInSaveRequest>, ) -> Result<Response<ParticipateInSaveResponse>, Status>
Participate in Save - Extension participates in save
Sourcepub async fn get_secret(
&mut self,
request: impl IntoRequest<GetSecretRequest>,
) -> Result<Response<GetSecretResponse>, Status>
pub async fn get_secret( &mut self, request: impl IntoRequest<GetSecretRequest>, ) -> Result<Response<GetSecretResponse>, Status>
Get Secret - Retrieve a secret from storage
Sourcepub async fn store_secret(
&mut self,
request: impl IntoRequest<StoreSecretRequest>,
) -> Result<Response<Empty>, Status>
pub async fn store_secret( &mut self, request: impl IntoRequest<StoreSecretRequest>, ) -> Result<Response<Empty>, Status>
Store Secret - Store a secret in storage
Sourcepub async fn delete_secret(
&mut self,
request: impl IntoRequest<DeleteSecretRequest>,
) -> Result<Response<Empty>, Status>
pub async fn delete_secret( &mut self, request: impl IntoRequest<DeleteSecretRequest>, ) -> Result<Response<Empty>, Status>
Delete Secret - Delete a secret from storage